==> haskell-stream-0.4.7.2-211-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-1zWBO51I7GsF2suhFjTAKq
key:                  Stream-0.4.7.2-1zWBO51I7GsF2suhFjTAKq
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  716f536d84a88979dffc8a8a81a63aeb
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stream
hs-libraries:         HSStream-0.4.7.2-1zWBO51I7GsF2suhFjTAKq
depends:
    QuickCheck-2.15.0.1-H5XTn9FxFUBGcmB1c3fPtp base-4.17.2.1
    lazysmallcheck-0.6-AmDuPsPRVQ34kdXMu8rwYU

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stream-0.4.7.2-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-LLB28Z1Symm1uXRUzsQrrv
key:                  Stream-0.4.7.2-LLB28Z1Symm1uXRUzsQrrv
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  f3340165b7d125bdbcd9f5ab52bd09b8
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stream
hs-libraries:         HSStream-0.4.7.2-LLB28Z1Symm1uXRUzsQrrv
depends:
    QuickCheck-2.15.0.1-DNiL2W0zGk61NvlUhQ7VCE base-4.17.2.1
    lazysmallcheck-0.6-AmDuPsPRVQ34kdXMu8rwYU

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
